package org.bitbucket.bradleysmithllc.etlunit.feature.h2_database;

import com.google.inject.Injector;
import org.bitbucket.bradleysmithllc.etlunit.feature.FeatureModule;
import org.bitbucket.bradleysmithllc.etlunit.feature.AbstractFeature;
import org.bitbucket.bradleysmithllc.etlunit.feature.database.DatabaseFeatureModule;

import javax.inject.Inject;
import java.util.Arrays;
import java.util.List;

@FeatureModule
public class H2DatabaseFeatureModule extends AbstractFeature {
	private static final List<String> prerequisites = Arrays.asList("logging", "database");
	private DatabaseFeatureModule databaseFeatureModule;
	private H2DatabaseImplementation hsqldbDatabaseImplementation;

	@Inject
	public void setDatabaseFeatureModule(DatabaseFeatureModule module)
	{
		databaseFeatureModule = module;
	}

	@Override
	public List<String> getPrerequisites() {
		return prerequisites;
	}

	@Override
	public void dispose()
	{
		hsqldbDatabaseImplementation.dispose();
	}

	@Override
	public void initialize(Injector inj)
	{
		hsqldbDatabaseImplementation = postCreate(new H2DatabaseImplementation());
		databaseFeatureModule.addDatabaseImplementation(hsqldbDatabaseImplementation);
	}

	public String getFeatureName() {
		return "h2-database";
	}
}